[][src]Module loco_protocol::network

Structs

ChannelConnection

ChannelConnection wrap command stream and process it. The response command will only send to sender channel. If response command doesn't have sender, It will treat as broadcast command and will be sent to every channel attached.

ChannelHandler

Handle command responses from ConnectionChannel

ConnectionChannel

ConnectionChannel holds Sender and Receiver crossed with another ConnectionChannel pair. Usually considered as user side and server side pair.

Enums

Error

Type Definitions

ResponseHandler